@@ -74,7 +74,9 @@ main (int argc, char* argv[])
         snprintf (newpreload, newlen + 1, "%s/lib/%s/pr13212.so", JAVA_HOME, ARCH);
     }
 
-  setenv ("LD_PRELOAD", newpreload, 1);
+  // XXX commenting out LD_PRELOAD hack because of problems
+  // see http://gcc.gnu.org/bugzilla/show_bug.cgi?id=13212
+  // setenv ("LD_PRELOAD", newpreload, 1);
 
   free (newpreload);
 
